API Reference
=============

..  example stuff

    TodoTxt
    -------

    .. autoclass:: pytodotxt.TodoTxt
       :members:
       :special-members: __init__


    Task
    ----

    .. autoclass:: pytodotxt.Task
       :members:
       :special-members: __init__


    TodoTxtParser
    -------------

    .. autoclass:: pytodotxt.TodoTxtParser
       :members:
       :special-members: __init__

CacheEntry
----------

.. autoclass:: metaindex.CacheEntry
   :members:


Query
-----

.. autoclass:: metaindex.Query
   :members:


Cache
-----

.. autoclass:: metaindex.MemoryCache
   :members:


Indexers
--------

.. autoclass:: metaindex.indexer.IndexerBase
   :members:

Humanizers
----------


.. autofunction:: metaindex.humanizer.register_humanizer

.. autoclass:: metaindex.humanizer.Priority
   :members:


SqlAccess
---------

.. autoclass:: metaindex.sql.SqlAccess
   :members:
